//---------------------------------------------------------------------------------------------------------------------
//
// RJ45 connector and CAT5E cable tester.
//
//
//---------------------------------------------------------------------------------------------------------------------

#include <90s2313.h>
#include <delay.h>

#define ACTIVITY_LED    PORTD.6     // LED on Tx board to flash so you can be sure something is happening
#define X_JUMPER        PIND.5      // Jumper to select normal or cross cable
#define TX_PORT         PORTB       // 8 bits to test one line at a time

// Arrays of output bytes - low bit turns on the LED on the Rx board
// One of the arrays are selected for either straight (normal) cable or a cross-over cable
// These values test lines in the order 8 down to 1 - but this makes no difference
flash char normal [] = {0x7f, 0xbf, 0xdf, 0xef, 0xf7, 0xfb, 0xfd, 0xfe};
flash char cross  [] = {0x7f, 0xbf, 0xfd, 0xef, 0xf7, 0xfe, 0xdf, 0xfb};

char loop;

void main(void)
{
    ACSR = 0x80;    // analogue comparator off
    DDRB = 0xff;    // PORT B all outputs
    DDRD = 0x40;    // PORTD 6 output (activity LED);

    PORTD = 0x20;   // pullup on PIN 5 (X patch jumper on) :- low = cross cable, high = straight cable
    PORTB = 0xff;   // Tx port high (all LEDs off)

    for (;;)                                                     // cycle forever
    {
        for (loop = 0; loop < 8; loop++)                         // cycle 0 - 7
        {
            TX_PORT = X_JUMPER ? normal [loop] : cross [loop];   // select bit to pull low depending on loop
                                                                 // and the bit array selected by the jumper
            ACTIVITY_LED = !ACTIVITY_LED;                        // toogle activty LED on Tx board
            delay_ms (250);                                      // wait a while...
        }
    }
}

//---------------------------------------------------------------------------------------------------------------------


